@@ -7,11 +7,16 @@ from htmlgen import Division, Paragraph, Preformatted
 
 class DivisionTest(TestCase):
 
-    def test_render(self):
+    def test_without_initial_content(self):
         div = Division()
         div.append("Test")
         assert_equal([b"<div>", b"Test", b"</div>"], list(iter(div)))
 
+    def test_with_initial_content(self):
+        div = Division("foo", "bar")
+        div.append("baz")
+        assert_equal("<div>foobarbaz</div>", str(div))
+
 
 class ParagraphTest(TestCase):
 
@@ -21,9 +26,10 @@ class ParagraphTest(TestCase):
         assert_equal([b"<p>", b"Test", b"</p>"], list(iter(p)))
 
     def test_with_initial_content(self):
-        p = Paragraph("Initial")
-        p.append("Test")
-        assert_equal([b"<p>", b"Initial", b"Test", b"</p>"], list(iter(p)))
+        p = Paragraph("Initial", "test")
+        p.append("content")
+        assert_equal([b"<p>", b"Initial", b"test", b"content", b"</p>"],
+                     list(iter(p)))
 
 
 class PreformattedTest(TestCase):
